@@ -13,6 +13,8 @@ import yaml
 
 def get_project_root() -> Path:
     r = Path(__file__).parent.parent
+    if 'site-packages' in r.parts:
+        r = r.parent.parent.parent
     return os.path.abspath(r)
 
 
